@@ -12,7 +12,7 @@ import tempfile
 
 from .common import Metadata, Module, dist_info_name
 from .wheel import WheelBuilder, _write_wheel_file
-from .sdist import SdistBuilder
+from flit.sdist import SdistBuilder
 
 from . import __version__
 
@@ -25,7 +25,7 @@ metadata_dict = {
     'summary': ('Distribution-building parts of Flit. '
                     'See flit package for more information'),
     'requires_dist': [
-        'pytoml',
+        'toml',
     ],
     'requires_python': '>=3.4',
     'classifiers': [
